"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DELETEUsersIdFollowedListsListIdRoute = exports.POSTUsersIdFollowedListsRoute = exports.GETUsersIdFollowedListsRoute = exports.GETListsIdFollowersRoute = void 0;
/**
 * Generates route for fetching users who are followers of a list:
 * - GET `/lists/:id/followers`
 * @param listId The list id to fetch followers of
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/lists/list-follows/api-reference/get-lists-id-followers
 *
 */
function GETListsIdFollowersRoute(listId) {
    return `/lists/${listId}/followers`;
}
exports.GETListsIdFollowersRoute = GETListsIdFollowersRoute;
/**
 * Generates route for fetching lists followed by a user:
 * - GET `/users/:id/followed_lists`
 * @param userId The user id whose followed lists are to be fetched
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/lists/list-follows/api-reference
 */
function GETUsersIdFollowedListsRoute(userId) {
    return `/users/${userId}/followed_lists`;
}
exports.GETUsersIdFollowedListsRoute = GETUsersIdFollowedListsRoute;
/**
 * Generates route for following a list:
 * - GET `/users/:id/followed_lists`
 * @param userId The user id to make the request on behalf of
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/lists/list-follows/api-reference
 */
function POSTUsersIdFollowedListsRoute(userId) {
    return `/users/${userId}/followed_lists`;
}
exports.POSTUsersIdFollowedListsRoute = POSTUsersIdFollowedListsRoute;
/**
 * Generates route for unfollowing a list:
 * - DELETE `/users/:id/followed_lists/:list_id`
 * @param userId The user id to make the request on behalf of
 * @param listId The list id to unfollow
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/lists/list-follows/api-reference/delete-users-id-followed-lists-list_id
 */
function DELETEUsersIdFollowedListsListIdRoute(userId, listId) {
    return `/users/${userId}/followed_lists/${listId}`;
}
exports.DELETEUsersIdFollowedListsListIdRoute = DELETEUsersIdFollowedListsListIdRoute;
/* eslint-enable max-len */
//# sourceMappingURL=ListFollows.js.map