"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DELETEListsIdMembersUserIdRoute = exports.POSTListsIdMembersRoute = exports.GETUsersIdListMembershipsRoute = exports.GETListsIdMembersRoute = void 0;
/**
 * Generates route for fetching members of a list:
 * - GET `/lists/:id/members`
 * @param listId The list id to fetch members of
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/lists/list-members/api-reference/get-lists-id-members
 */
function GETListsIdMembersRoute(listId) {
    return `/lists/${listId}/members`;
}
exports.GETListsIdMembersRoute = GETListsIdMembersRoute;
/**
 * Generates route for fetching lists in which a user is member:
 * - GET `/users/:id/list_memberships`
 * @param userId The user id to fetch list membership of
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/lists/list-members/api-reference/get-users-id-list_memberships
 */
function GETUsersIdListMembershipsRoute(userId) {
    return `/users/${userId}/list_memberships`;
}
exports.GETUsersIdListMembershipsRoute = GETUsersIdListMembershipsRoute;
/**
 * Generates route for adding a member to a list:
 * - `POST /lists/:id/members`
 * @param listId The list id to add the member to
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/lists/list-members/api-reference/post-lists-id-members
 */
function POSTListsIdMembersRoute(listId) {
    return `/lists/${listId}/members`;
}
exports.POSTListsIdMembersRoute = POSTListsIdMembersRoute;
/**
 * Generates route for removing a member from a list:
 * - DELETE `/lists/:id/members/:user_id`
 * @param listId The list id to remove the member from
 * @param userId The user id to remove from the list
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/lists/list-members/api-reference/delete-lists-id-members-user_id
 */
function DELETEListsIdMembersUserIdRoute(listId, userId) {
    return `/lists/${listId}/members/${userId}`;
}
exports.DELETEListsIdMembersUserIdRoute = DELETEListsIdMembersUserIdRoute;
/* eslint-enable max-len */
//# sourceMappingURL=ListMembers.js.map