/**
 * The body for creating a list
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/lists/manage-lists/api-reference/post-lists
 */
export interface POSTListsJSONBody {
    /**
     * The name of the list
     */
    name: string;
    /**
     * The description of the list
     */
    description?: string;
    /**
     * Whether the list should be private
     */
    private?: boolean;
}
/**
 * The response of creating a list
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/lists/manage-lists/api-reference/post-lists
 */
export interface POSTListsResponse {
    data: {
        /**
         * The id of the list
         */
        id: string;
        /**
         * The name of the list
         */
        name: string;
    };
}
/**
 * Generates route for creating a list:
 * - POST `/lists`
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/lists/manage-lists/api-reference/post-lists
 */
export declare function POSTListsRoute(): "/lists";
/**
 * The response of deleting a list
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/lists/manage-lists/api-reference/delete-lists-id
 */
export interface DELETEListsIdResponse {
    data: {
        deleted: boolean;
    };
}
/**
 * Generates route for deleting a list:
 * - DELETE `/lists/:id`
 * @param listId The list id to delete
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/lists/manage-lists/api-reference/delete-lists-id
 */
export declare function DELETEListsIdRoute(listId: string): `/lists/${string}`;
/**
 * The body for updating a list
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/lists/manage-lists/api-reference/put-lists-id
 */
export declare type PUTListsIdJSONBody = Partial<POSTListsJSONBody>;
/**
 * The response of updating a list
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/lists/manage-lists/api-reference/put-lists-id
 */
export interface PUTListsIdResponse {
    data: {
        updated: boolean;
    };
}
/**
 * Generates route for updating a list:
 * - PUT `/lists/:id`
 * @param listId The list id to update
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/lists/manage-lists/api-reference/put-lists-id
 */
export declare function PUTListsIdRoute(listId: string): `/lists/${string}`;
//# sourceMappingURL=ManageLists.d.ts.map