import type { MultipleListsLookupQuery, MultipleListsLookupResponse } from './index';
/**
 * The query for fetching list pinned by a user
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/lists/pinned-lists/api-reference/get-users-id-pinned_lists
 */
export interface GETUsersIdPinnedListsQuery extends MultipleListsLookupQuery {
    max_results?: number;
    pagination_token?: string;
}
/**
 * The response of fetching list pinned by a user
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/lists/pinned-lists/api-reference/get-users-id-pinned_lists
 */
export interface GETUsersIdPinnedListsResponse extends MultipleListsLookupResponse {
    meta: {
        result_count: number;
        previous_token?: string;
        next_token?: string;
    };
}
/**
 * Generates route for fetching lists pinned by a user:
 * - GET `/users/:id/pinned_lists`
 * @param userId The user id whose pinned lists are to be fetched
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/lists/pinned-lists/api-reference/get-users-id-pinned_lists
 */
export declare function GETUsersIdPinnedListsRoute(userId: string): `/users/${string}/pinned_lists`;
/**
 * The body for pinning a list
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/lists/pinned-lists/api-reference/post-users-id-pinned-lists
 */
export interface POSTUsersIdPinnedListsJSONBody {
    list_id: string;
}
/**
 * The respone of pinning a list
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/lists/pinned-lists/api-reference/post-users-id-pinned-lists
 */
export interface POSTUsersIdPinnedListsResponse {
    data: {
        pinned: boolean;
    };
}
/**
 * Generates route for pinning a list:
 * - POST `/users/:id/pinned_lists`
 * @param userId The user id to make the request on behalf of
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/lists/pinned-lists/api-reference/post-users-id-pinned-lists
 */
export declare function POSTUsersIdPinnedListsRoute(userId: string): `/users/${string}/pinned_lists`;
/**
 * The response of unpinning a list
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/lists/pinned-lists/api-reference/delete-users-id-pinned-lists-list_id
 */
export interface DELETEUsersIdPinnedListsListIdResponse {
    data: {
        pinned: false;
    };
}
/**
 * Generates route for unpinning a list:
 * - DELETE `/users/:id/pinned_lists/:list_id`
 * @param userId The user id to make the request on behalf of
 * @param listId The list id to unpin
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/lists/pinned-lists/api-reference/delete-users-id-pinned-lists-list_id
 */
export declare function DELETEUsersIdPinnedListsListIdRoute(userId: string, listId: string): `/users/${string}/pinned_lists/${string}`;
//# sourceMappingURL=PinnedLists.d.ts.map