"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DELETEUsersIdPinnedListsListIdRoute = exports.POSTUsersIdPinnedListsRoute = exports.GETUsersIdPinnedListsRoute = void 0;
/**
 * Generates route for fetching lists pinned by a user:
 * - GET `/users/:id/pinned_lists`
 * @param userId The user id whose pinned lists are to be fetched
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/lists/pinned-lists/api-reference/get-users-id-pinned_lists
 */
function GETUsersIdPinnedListsRoute(userId) {
    return `/users/${userId}/pinned_lists`;
}
exports.GETUsersIdPinnedListsRoute = GETUsersIdPinnedListsRoute;
/**
 * Generates route for pinning a list:
 * - POST `/users/:id/pinned_lists`
 * @param userId The user id to make the request on behalf of
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/lists/pinned-lists/api-reference/post-users-id-pinned-lists
 */
function POSTUsersIdPinnedListsRoute(userId) {
    return `/users/${userId}/pinned_lists`;
}
exports.POSTUsersIdPinnedListsRoute = POSTUsersIdPinnedListsRoute;
/**
 * Generates route for unpinning a list:
 * - DELETE `/users/:id/pinned_lists/:list_id`
 * @param userId The user id to make the request on behalf of
 * @param listId The list id to unpin
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/lists/pinned-lists/api-reference/delete-users-id-pinned-lists-list_id
 */
function DELETEUsersIdPinnedListsListIdRoute(userId, listId) {
    return `/users/${userId}/pinned_lists/${listId}`;
}
exports.DELETEUsersIdPinnedListsListIdRoute = DELETEUsersIdPinnedListsListIdRoute;
/* eslint-enable max-len */
//# sourceMappingURL=PinnedLists.js.map