"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GETSpacesIdTweetsRoute = exports.GETSpacesByCreatorIdsRoute = exports.GETSpacesIdBuyersRoute = exports.GETSpacesRoute = exports.GETSpacesIdRoute = void 0;
/**
 * Generates route for fetching a space by its id
 * - GET `/spaces/:id`
 * @param spaceId The space id to fetch
 */
function GETSpacesIdRoute(spaceId) {
    return `/spaces/${spaceId}`;
}
exports.GETSpacesIdRoute = GETSpacesIdRoute;
/**
 * Generates route for fetching spaces by their ids:
 * - GET `/spaces`
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/spaces/lookup/api-reference/get-spaces
 */
function GETSpacesRoute() {
    return `/spaces`;
}
exports.GETSpacesRoute = GETSpacesRoute;
/**
 * Generates route for fetching users who purchased a ticket for a space:
 * - GET `/spaces/:id/buyers`
 * @param spaceId The space id whose buyers are to be fetched
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/spaces/lookup/api-reference/get-spaces-id-buyers
 */
function GETSpacesIdBuyersRoute(spaceId) {
    return `/spaces/${spaceId}/buyers`;
}
exports.GETSpacesIdBuyersRoute = GETSpacesIdBuyersRoute;
/**
 * Generates route for fetching spaces created by users:
 * - GET `/spaces/by/creator_ids`
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/spaces/lookup/api-reference/get-spaces-by-creator-ids
 */
function GETSpacesByCreatorIdsRoute() {
    return `/spaces/by/creator_ids`;
}
exports.GETSpacesByCreatorIdsRoute = GETSpacesByCreatorIdsRoute;
/**
 * Generates route for fetching tweets shared in a space:
 * - GET `/spaces/:id/tweets`
 * @param spaceId The space id whose shared tweets are to be fetched
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/spaces/lookup/api-reference/get-spaces-id-tweets
 */
function GETSpacesIdTweetsRoute(spaceId) {
    return `/spaces/${spaceId}/tweets`;
}
exports.GETSpacesIdTweetsRoute = GETSpacesIdTweetsRoute;
//# sourceMappingURL=SpacesLookup.js.map