"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DELETEUsersIdBookmarksTweetIdRoute = exports.POSTUsersIdBookmarksRoute = exports.GETUsersIdBookmarksRoute = void 0;
/**
 * Generates route for fetching bookmarked tweets
 * - GET `/users/:id/bookmarks`
 * @param userId The user id whose bookmarked tweets are to be fetched
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/tweets/bookmarks/api-reference/get-users-id-bookmarks
 */
function GETUsersIdBookmarksRoute(userId) {
    return `/users/${userId}/bookmarks`;
}
exports.GETUsersIdBookmarksRoute = GETUsersIdBookmarksRoute;
/**
 * Generates route for bookmarking a tweet:
 * - POST `/users/:id/bookmarks`
 * @param tweetId The tweet id to bookmark
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/tweets/bookmarks/api-reference/post-users-id-bookmarks
 */
function POSTUsersIdBookmarksRoute(tweetId) {
    return `/users/${tweetId}/bookmarks`;
}
exports.POSTUsersIdBookmarksRoute = POSTUsersIdBookmarksRoute;
/**
 * Generates route for removing a bookmark of a tweet:
 * - DELETE `/users/:id/bookmarks/:tweet_id`
 * @param userId The user id whose bookmarked tweet is to be removed
 * @param tweetId The tweet whose bookmark is to be removed
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/tweets/bookmarks/api-reference/delete-users-id-bookmarks-tweet_id
 */
function DELETEUsersIdBookmarksTweetIdRoute(userId, tweetId) {
    return `/users/${userId}/bookmarks/${tweetId}`;
}
exports.DELETEUsersIdBookmarksTweetIdRoute = DELETEUsersIdBookmarksTweetIdRoute;
//# sourceMappingURL=Bookmarks.js.map