import type { MergeExclusive } from '../misc';
import type { SingleTweetLookupQuery, SingleTweetLookupResponse } from './index';
export interface AddFilteredTweetStreamRulesJSONBody {
    add: Array<{
        value: string;
        tag?: string;
    }>;
}
export interface RemoveFilteredTweetStreamRulesJSONBody {
    delete: MergeExclusive<{
        ids: Array<string>;
    }, {
        values: Array<string>;
    }>;
}
export interface AddFilteredTweetStreamRulesResponseMeta {
    sent: string;
    summary: {
        created: number;
        not_created: number;
        valid: number;
        invalid: number;
    };
}
export interface RemoveFilteredTweetStreamRulesResponseMeta {
    sent: string;
    summary: {
        deleted: number;
        not_deleted: number;
    };
}
/**
 * The query for adding or deleting filtered-tweet-stream rules
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/tweets/filtered-stream/api-reference/post-tweets-search-stream-rules
 */
export interface POSTTweetsSearchStreamRulesQuery {
    dry_run?: boolean;
}
/**
 * The body for adding or deleting filtered-tweet-stream rules
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/tweets/filtered-stream/api-reference/post-tweets-search-stream-rules
 */
export declare type POSTTweetsSearchStreamRulesJSONBody = MergeExclusive<AddFilteredTweetStreamRulesJSONBody, RemoveFilteredTweetStreamRulesJSONBody>;
/**
 * The response of adding or deleting filtered-tweet-stream rules
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/tweets/filtered-stream/api-reference/post-tweets-search-stream-rules
 */
export declare type POSTTweetsSearchStreamRulesResponse = MergeExclusive<{
    data: Array<{
        id: string;
        value: string;
        tag?: string;
    }>;
    meta: AddFilteredTweetStreamRulesResponseMeta;
}, {
    meta: RemoveFilteredTweetStreamRulesResponseMeta;
}>;
/**
 * Generates link for adding or deleting filtered-tweet-stream rules:
 * - POST `/tweets/search/stream/rules`
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/tweets/filtered-stream/api-reference/post-tweets-search-stream-rules
 */
export declare function POSTTweetsSearchStreamRulesRoute(): "/tweets/search/stream/rules";
/**
 * The query for fetching currently active filtered-tweet-stream rules
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/tweets/filtered-stream/api-reference/get-tweets-search-stream-rules
 */
export interface GETTweetsSearchStreamRulesQuery {
    ids?: Array<string>;
}
/**
 * The response of fetching currently active filtered-tweet-stream rules
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/tweets/filtered-stream/api-reference/get-tweets-search-stream-rules
 */
export interface GETTweetsSearchStreamRulesResponse {
    data: Array<{
        id: string;
        value: string;
        tag?: string;
    }>;
    meta: {
        sent: string;
    };
}
/**
 * Generates route for fetching currently active filtered-tweet-stream rules:
 * - GET `/tweets/search/stream/rules`
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/tweets/filtered-stream/api-reference/get-tweets-search-stream-rules
 */
export declare function GETTweetsSearchStreamRulesRoute(): "/tweets/search/stream/rules";
/**
 * The query to connect with the filtered-tweet-stream
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/tweets/filtered-stream/api-reference/get-tweets-search-stream
 */
export interface GETTweetsSearchStreamQuery extends SingleTweetLookupQuery {
    backfill_minutes?: number;
}
/**
 * The response of the filtered-tweet-stream
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/tweets/filtered-stream/api-reference/get-tweets-search-stream
 */
export interface GETTweetsSearchStreamResponse extends SingleTweetLookupResponse {
    matching_rules: Array<{
        id: string;
        tag?: string;
    }>;
}
/**
 * Generates route to connect with the filtered-tweet-stream:
 * - GET `/tweets/search/stream`
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/tweets/filtered-stream/api-reference/get-tweets-search-stream
 */
export declare function GETTweetsSearchStreamRoute(): "/tweets/search/stream";
//# sourceMappingURL=FilteredStream.d.ts.map