"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DELETEUsersIdLikesTweetIdRoute = exports.POSTUsersIdLikesRoute = exports.GETUsersIdLikedTweetsRoute = exports.GETTweetsIdLikingUsersRoute = void 0;
/**
 * Generates route for fetching users who liked a tweet:
 * - GET `/tweets/:id/liking_users`
 * @param tweetId The tweet id whose liking users are to be fetched
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/tweets/likes/api-reference/get-tweets-id-liking_users
 */
function GETTweetsIdLikingUsersRoute(tweetId) {
    return `/tweets/${tweetId}/liking_users`;
}
exports.GETTweetsIdLikingUsersRoute = GETTweetsIdLikingUsersRoute;
/**
 * Generates route for fetching tweets liked by a user:
 * - GET `/users/:id/liked_tweets`
 * @param userId The user id whose liked tweets are to be fetched
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/tweets/likes/api-reference/get-users-id-liked_tweets
 */
function GETUsersIdLikedTweetsRoute(userId) {
    return `/users/${userId}/liked_tweets`;
}
exports.GETUsersIdLikedTweetsRoute = GETUsersIdLikedTweetsRoute;
/**
 * Generates route for liking a tweet:
 * - POST `/users/:id/likes`
 * @param userId The user id to like the tweet on behalf of
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/tweets/likes/api-reference/post-users-id-likes
 */
function POSTUsersIdLikesRoute(userId) {
    return `/users/${userId}/likes`;
}
exports.POSTUsersIdLikesRoute = POSTUsersIdLikesRoute;
/**
 * Generates route for unliking a tweet:
 * - DELETE `/users/:id/likes/:tweet_id`
 * @param userId The user id to unlike the tweet on behalf of
 * @param tweetId The tweet id to unlike
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/tweets/likes/api-reference/delete-users-id-likes-tweet_id
 */
function DELETEUsersIdLikesTweetIdRoute(userId, tweetId) {
    return `/users/${userId}/likes/${tweetId}`;
}
exports.DELETEUsersIdLikesTweetIdRoute = DELETEUsersIdLikesTweetIdRoute;
//# sourceMappingURL=Likes.js.map