"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DELETEUsersIdRetweetsSourceTweetIdRoute = exports.POSTUsersIdRetweetsRoute = exports.GETTweetsIdRetweetedByRoute = void 0;
/**
 * Generates route for fetching users who retweeted a tweet:
 * - GET `/tweets/:id/retweeted_by`
 * @param tweetId The tweet id whose retweeting users are to be fetched
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/tweets/retweets/api-reference/get-tweets-id-retweeted_by
 */
function GETTweetsIdRetweetedByRoute(tweetId) {
    return `/tweets/${tweetId}/retweeted_by`;
}
exports.GETTweetsIdRetweetedByRoute = GETTweetsIdRetweetedByRoute;
/**
 * Generates route for retweeting a tweet:
 * - POST `/users/:id/retweets`
 * @param userId The user id to retweet on behalf of
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/tweets/retweets/api-reference/post-users-id-retweets
 */
function POSTUsersIdRetweetsRoute(userId) {
    return `/users/${userId}/retweets`;
}
exports.POSTUsersIdRetweetsRoute = POSTUsersIdRetweetsRoute;
/**
 * Generates route for removing a retweet of a tweet:
 * - DELETE `/users/:id/retweets/:source_tweet_id`
 * @param userId The user id to remove the retweet on behalf of
 * @param tweetId The tweet id whose retweet is to be removed
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/tweets/retweets/api-reference/delete-users-id-retweets-tweet_id
 */
function DELETEUsersIdRetweetsSourceTweetIdRoute(userId, tweetId) {
    return `/users/${userId}/retweets/${tweetId}`;
}
exports.DELETEUsersIdRetweetsSourceTweetIdRoute = DELETEUsersIdRetweetsSourceTweetIdRoute;
/* eslint-enable max-len */
//# sourceMappingURL=Retweets.js.map