/**
 * The query for fetching count of recent tweets that match a search query
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/tweets/counts/api-reference/get-tweets-counts-recent
 */
export interface GETTweetsCountsRecentQuery {
    query: string;
    end_time?: string;
    granularity?: 'minute' | 'hour' | 'day';
    since_id?: string;
    start_time?: string;
    until_id?: string;
    next_token?: string;
}
/**
 * The response of fetching count of recent tweets that match a search query
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/tweets/counts/api-reference/get-tweets-counts-recent
 */
export interface GETTweetsCountsRecentResponse {
    data: Array<{
        end: string;
        start: string;
        tweet_count: number;
    }>;
    meta: {
        next_token?: string;
        total_tweet_count: number;
    };
}
/**
 * Generates route for fetching count of recent tweets that match a search query:
 * - GET `/tweets/counts/recent`
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/tweets/counts/api-reference/get-tweets-counts-recent
 */
export declare function GETTweetsCountsRecentRoute(): "/tweets/counts/recent";
/**
 * The query for fetching count of full-archive tweets that match a search query
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/tweets/counts/api-reference/get-tweets-counts-all
 */
export declare type GETTweetsCountsAllQuery = GETTweetsCountsRecentQuery;
/**
 * The response of fetching count of full-archive tweets that match a search query
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/tweets/counts/api-reference/get-tweets-counts-all
 */
export declare type GETTweetsCountsAllResponse = GETTweetsCountsRecentResponse;
/**
 * Generates route for fetching count of full-archive tweets that match a search query:
 * - GET `/tweets/counts/all`
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/tweets/counts/api-reference/get-tweets-counts-all
 */
export declare function GETTweetsCountsAllRoute(): "/tweets/counts/all";
//# sourceMappingURL=TweetCounts.d.ts.map