import type { MultipleTweetsLookupQuery, MultipleTweetsLookupResponse, SingleTweetLookupQuery, SingleTweetLookupResponse } from './index';
/**
 * The query for fetching multiple tweets by ids
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/tweets/lookup/api-reference/get-tweets
 */
export interface GETTweetsQuery extends MultipleTweetsLookupQuery {
    ids: Array<string>;
}
/**
 * The response of fetching multiple tweets by ids
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/tweets/lookup/api-reference/get-tweets
 */
export declare type GETTweetsResponse = MultipleTweetsLookupResponse;
/**
 * Generates route for fetching multiple tweets by ids:
 * - GET `/tweets`
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/tweets/lookup/api-reference/get-tweets
 */
export declare function GETTweetsRoute(): "/tweets";
/**
 * The query for fetching a single tweet by id
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/tweets/lookup/api-reference/get-tweets-id
 */
export declare type GETTweetsIdQuery = SingleTweetLookupQuery;
/**
 * The response for the request of fetching a single tweet by ID
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/tweets/lookup/api-reference/get-tweets-id
 */
export declare type GETTweetsIdResponse = SingleTweetLookupResponse;
/**
 * Generates route for fetching a tweet by id:
 * - GET `/tweets/:id`
 * @param tweetId The tweet id to fetch
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/tweets/lookup/api-reference/get-tweets-id
 */
export declare function GETTweetsIdRoute(tweetId: string): `/tweets/${string}`;
//# sourceMappingURL=TweetsLookup.d.ts.map