"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DELETEUsersSourceUserIdFollowingTargetUserIdRoute = exports.POSTUsersIdFollowingRoute = exports.GETUsersIdFollowersRoute = exports.GETUsersIdFollowingRoute = void 0;
/**
 * Generates route for fetching users followed by a user:
 * - GET `/users/:id/following`
 * @param userId The user id whose following is to be fetched
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/users/follows/api-reference/get-users-id-following
 */
function GETUsersIdFollowingRoute(userId) {
    return `/users/${userId}/following`;
}
exports.GETUsersIdFollowingRoute = GETUsersIdFollowingRoute;
/**
 * Generates route for fetching followers of a user:
 * - GET `/users/:id/followers`
 * @param userId The user id whose followers are to be fetched
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/users/follows/api-reference/get-users-id-followers
 */
function GETUsersIdFollowersRoute(userId) {
    return `/users/${userId}/followers`;
}
exports.GETUsersIdFollowersRoute = GETUsersIdFollowersRoute;
/**
 * Generates route for following a user:
 * - POST `/users/:id/following`
 * @param userId The user id to make request on behalf of
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/users/follows/api-reference/post-users-source_user_id-following
 */
function POSTUsersIdFollowingRoute(userId) {
    return `/users/${userId}/following`;
}
exports.POSTUsersIdFollowingRoute = POSTUsersIdFollowingRoute;
/**
 * Generates route for unfollowing a user:
 * - DELETE `/users/:source_user_id/following/:target_user_id`
 * @param sourceUserId The user id to make request on behalf of
 * @param targetUserId The user id to unfollow
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/users/follows/api-reference/delete-users-source_id-following
 */
function DELETEUsersSourceUserIdFollowingTargetUserIdRoute(sourceUserId, targetUserId) {
    return `/users/${sourceUserId}/following/${targetUserId}`;
}
exports.DELETEUsersSourceUserIdFollowingTargetUserIdRoute = DELETEUsersSourceUserIdFollowingTargetUserIdRoute;
//# sourceMappingURL=Follows.js.map