import type { MultipleUsersLookupQuery, MultipleUsersLookupResponse } from './index';
/**
 * The query for fetching users muted by a user
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/users/mutes/api-reference/get-users-muting
 */
export interface GETUsersIdMutingQuery extends MultipleUsersLookupQuery {
    max_results?: number;
    pagination_token?: string;
}
/**
 * The response of fetching users muted by a user
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/users/mutes/api-reference/get-users-muting
 */
export interface GETUsersIdMutingResponse extends MultipleUsersLookupResponse {
    meta: {
        result_count: number;
        previous_token?: string;
        next_token?: string;
    };
}
/**
 * Generates route for fetching users muted by a user:
 * - GET `/users/:id/muting`
 * @param userId The user id whose muted users are to be fetched
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/users/mutes/api-reference/get-users-muting
 */
export declare function GETUsersIdMutingRoute(userId: string): `/users/${string}/muting`;
/**
 * The body for muting a user
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/users/mutes/api-reference/post-users-user_id-muting
 */
export interface POSTUsersIdMutingJSONBody {
    target_user_id: string;
}
/**
 * The response of muting a user
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/users/mutes/api-reference/post-users-user_id-muting
 */
export interface POSTUsersIdMutingResponse {
    data: {
        muting: boolean;
    };
}
/**
 * Generates route for muting a user:
 * - POST `/users/:id/muting`
 * @param userId The user id to make request on behalf of
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/users/mutes/api-reference/post-users-user_id-muting
 */
export declare function POSTUsersIdMutingRoute(userId: string): `/users/${string}/muting`;
/**
 * The response of unmuting a user
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/users/mutes/api-reference/delete-users-user_id-muting
 */
export interface DELETEUsersSourceUserIdMutingTargetUserIdResponse {
    data: {
        muting: boolean;
    };
}
/**
 * Generates route for unmuting a user:
 * - DELETE `/users/:source_user_id/muting/:target_user_id`
 * @param sourceUserId The user id to make request on behalf of
 * @param targetUserId The user id to unmute
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/users/mutes/api-reference/delete-users-user_id-muting
 */
export declare function DELETEUsersSourceUserIdMutingTargetUserId(sourceUserId: string, targetUserId: string): `/users/${string}/muting/${string}`;
//# sourceMappingURL=Mutes.d.ts.map