"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DELETEUsersSourceUserIdMutingTargetUserId = exports.POSTUsersIdMutingRoute = exports.GETUsersIdMutingRoute = void 0;
/**
 * Generates route for fetching users muted by a user:
 * - GET `/users/:id/muting`
 * @param userId The user id whose muted users are to be fetched
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/users/mutes/api-reference/get-users-muting
 */
function GETUsersIdMutingRoute(userId) {
    return `/users/${userId}/muting`;
}
exports.GETUsersIdMutingRoute = GETUsersIdMutingRoute;
/**
 * Generates route for muting a user:
 * - POST `/users/:id/muting`
 * @param userId The user id to make request on behalf of
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/users/mutes/api-reference/post-users-user_id-muting
 */
function POSTUsersIdMutingRoute(userId) {
    return `/users/${userId}/muting`;
}
exports.POSTUsersIdMutingRoute = POSTUsersIdMutingRoute;
/**
 * Generates route for unmuting a user:
 * - DELETE `/users/:source_user_id/muting/:target_user_id`
 * @param sourceUserId The user id to make request on behalf of
 * @param targetUserId The user id to unmute
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/users/mutes/api-reference/delete-users-user_id-muting
 */
function DELETEUsersSourceUserIdMutingTargetUserId(sourceUserId, targetUserId) {
    return `/users/${sourceUserId}/muting/${targetUserId}`;
}
exports.DELETEUsersSourceUserIdMutingTargetUserId = DELETEUsersSourceUserIdMutingTargetUserId;
//# sourceMappingURL=Mutes.js.map