import type { MultipleUsersLookupQuery, MultipleUsersLookupResponse, SingleUserLookupQuery, SingleUserLookupResponse } from './index';
/**
 * The query for fetching users by their ids
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/users/lookup/api-reference/get-users
 */
export interface GETUsersQuery extends MultipleUsersLookupQuery {
    ids: Array<string>;
}
/**
 * The response of fetching users by their ids
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/users/lookup/api-reference/get-users
 */
export declare type GETUsersResponse = MultipleUsersLookupResponse;
/**
 * Generates route for fetching users by their ids:
 * - GET `/users`
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/users/lookup/api-reference/get-users
 */
export declare function GETUsersRoute(): "/users";
/**
 * The query for fetching a user by its id
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/users/lookup/api-reference/get-users-id
 */
export declare type GETUsersIdQuery = SingleUserLookupQuery;
/**
 * The response of fetching a user by its id
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/users/lookup/api-reference/get-users-id
 */
export declare type GETUsersIdResponse = SingleUserLookupResponse;
/**
 * Generates route for fetching a user by its id:
 * - GET `/users/:id`
 * @param userId The user id to fetch
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/users/lookup/api-reference/get-users-id
 */
export declare function GETUsersIdRoute(userId: string): `/users/${string}`;
/**
 * The query for fetching users by their usernames
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/users/lookup/api-reference/get-users-by
 */
export interface GETUsersByQuery extends MultipleUsersLookupQuery {
    usernames: Array<string>;
}
/**
 * The response of fetching users by their usernames
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/users/lookup/api-reference/get-users-by
 */
export declare type GETUsersByResponse = MultipleUsersLookupResponse;
/**
 * Generates route for fetching users by their usernames:
 * - GET `/users/by`
 *
 * @see  https://developer.twitter.com/en/docs/twitter-api/users/lookup/api-reference/get-users-by
 */
export declare function GETUsersByRoute(): "/users/by";
/**
 * The query for fetching a user by its username
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/users/lookup/api-reference/get-users-by-username-username
 */
export declare type GETUsersByUsernameUsernameQuery = SingleUserLookupQuery;
/**
 * The response of fetching a user by its username
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/users/lookup/api-reference/get-users-by-username-username
 */
export declare type GETUsersByUsernameUsernameResponse = SingleUserLookupResponse;
/**
 * Generates route for fetching a user by its username:
 * - GET `/users/by/username/:username`
 * @param username The username to fetch
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/users/lookup/api-reference/get-users-by-username-username
 */
export declare function GETUsersByUsernameUsernameRoute(username: string): `/users/by/username/${string}`;
/**
 * The query for fetching an authorized user
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/users/lookup/api-reference/get-users-me
 */
export declare type GETUsersMeQuery = SingleUserLookupQuery;
/**
 * The response of fetching an authorized user
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/users/lookup/api-reference/get-users-me
 */
export declare type GETUsersMeResponse = SingleUserLookupResponse;
/**
 * Generates route for fetching an authorized user:
 * - GET `/users/me`
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/users/lookup/api-reference/get-users-me
 */
export declare function GETUsersMeRoute(): "/users/me";
//# sourceMappingURL=UsersLookup.d.ts.map