"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GETUsersMeRoute = exports.GETUsersByUsernameUsernameRoute = exports.GETUsersByRoute = exports.GETUsersIdRoute = exports.GETUsersRoute = void 0;
/**
 * Generates route for fetching users by their ids:
 * - GET `/users`
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/users/lookup/api-reference/get-users
 */
function GETUsersRoute() {
    return `/users`;
}
exports.GETUsersRoute = GETUsersRoute;
/**
 * Generates route for fetching a user by its id:
 * - GET `/users/:id`
 * @param userId The user id to fetch
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/users/lookup/api-reference/get-users-id
 */
function GETUsersIdRoute(userId) {
    return `/users/${userId}`;
}
exports.GETUsersIdRoute = GETUsersIdRoute;
/**
 * Generates route for fetching users by their usernames:
 * - GET `/users/by`
 *
 * @see  https://developer.twitter.com/en/docs/twitter-api/users/lookup/api-reference/get-users-by
 */
function GETUsersByRoute() {
    return `/users/by`;
}
exports.GETUsersByRoute = GETUsersByRoute;
/**
 * Generates route for fetching a user by its username:
 * - GET `/users/by/username/:username`
 * @param username The username to fetch
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/users/lookup/api-reference/get-users-by-username-username
 */
function GETUsersByUsernameUsernameRoute(username) {
    return `/users/by/username/${username}`;
}
exports.GETUsersByUsernameUsernameRoute = GETUsersByUsernameUsernameRoute;
/**
 * Generates route for fetching an authorized user:
 * - GET `/users/me`
 *
 * @see https://developer.twitter.com/en/docs/twitter-api/users/lookup/api-reference/get-users-me
 */
function GETUsersMeRoute() {
    return `/users/me`;
}
exports.GETUsersMeRoute = GETUsersMeRoute;
//# sourceMappingURL=UsersLookup.js.map